/**
 * FastPriorityQueue.js : a fast heap-based priority queue  in JavaScript.
 * (c) the authors
 * Licensed under the Apache License, Version 2.0.
 *
 * Speed-optimized heap-based priority queue for modern browsers and JavaScript engines.
 *
 * Usage :
         Installation (in shell, if you use node):
         $ npm install fastpriorityqueue

         Running test program (in JavaScript):

         // var FastPriorityQueue = require("fastpriorityqueue");// in node
         var x = new FastPriorityQueue();
         x.add(1);
         x.add(0);
         x.add(5);
         x.add(4);
         x.add(3);
         x.peek(); // should return 0, leaves x unchanged
         x.size; // should return 5, leaves x unchanged
         while(!x.isEmpty()) {
           console.log(x.poll());
         } // will print 0 1 3 4 5
         x.trim(); // (optional) optimizes memory usage
 */
export interface Comparator {
    (lhs: number, rhs: number): boolean;
}
export interface Item<T> {
    object: T;
    priority: number;
}
declare class FastPriorityQueue<T> {
    array: Item<T>[];
    size: number;
    compare: Comparator;
    constructor(comparator?: Comparator);
    add(myval: T, priority: number): Item<T>;
    heapify(arr: Item<T>[]): void;
    peek(): Item<T>;
    poll(): Item<T>;
    trim(): void;
    isEmpty(): boolean;
    has(object: T): boolean;
    private _percolateUp(i);
    private _percolateDown(i);
}
export default FastPriorityQueue;
